Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(378)

Unified Diff: sky/examples/widgets/spinning_mixed.dart

Issue 1183913006: Rename AppView to SkyBinding. (Closed) Base URL: https://github.com/domokit/mojo.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sky/examples/widgets/sector.dart ('k') | sky/sdk/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sky/examples/widgets/spinning_mixed.dart
diff --git a/sky/examples/widgets/spinning_mixed.dart b/sky/examples/widgets/spinning_mixed.dart
index 9bd00702f24aa170eb1808f4f252848e6fc6d5b7..38ef903fe2bbb9fe77b84f7b6e3acb58f1159382 100644
--- a/sky/examples/widgets/spinning_mixed.dart
+++ b/sky/examples/widgets/spinning_mixed.dart
@@ -75,12 +75,12 @@ void rotate(double timeStamp) {
void main() {
// Because we're going to use Widgets, we want to initialise its
// AppView, not use the default one. We don't really need to do
// this, because RenderBoxToWidgetAdapter does it for us, but
// it's good practice in case we happen to not have a
// RenderBoxToWidgetAdapter in our tree at startup, or in case we
// want a renderViewOverride.
- WidgetAppView.initWidgetAppView();
+ WidgetSkyBinding.initWidgetSkyBinding();
RenderFlex flexRoot = new RenderFlex(direction: FlexDirection.vertical);
@@ -94,6 +94,6 @@ void main() {
transformBox = new RenderTransform(child: flexRoot, transform: new Matrix4.identity());
RenderPadding root = new RenderPadding(padding: new EdgeDims.all(20.0), child: transformBox);
- WidgetAppView.appView.root = root;
+ WidgetSkyBinding.skyBinding.root = root;
addPersistentFrameCallback(rotate);
}
« no previous file with comments | « sky/examples/widgets/sector.dart ('k') | sky/sdk/BUILD.gn » ('j') | no next file with comments »
@@ -75,12 +75,12 @@ void rotate(double timeStamp) {
void main() {
// Because we're going to use Widgets, we want to initialise its
- // AppView, not use the default one. We don't really need to do
+ // SkyBinding, not use the default one. We don't really need to do
// this, because RenderBoxToWidgetAdapter does it for us, but
// it's good practice in case we happen to not have a

Powered by Google App Engine
This is Rietveld 408576698